@@ -23,6 +23,9 @@ class CampaignLogEventType(Enum):
     ADDED_EMAIL_STEP = 'ADDED_EMAIL_STEP'
     ADDED_DELAY_AFTER = 'ADDED_DELAY_AFTER'
     EDITED_DELAY_AFTER = 'EDITED_DELAY_AFTER'
+    ACCEPTED_RECOMMENDATION = 'ACCEPTED_RECOMMENDATION'
+    REJECTED_RECOMMENDATION = 'REJECTED_RECOMMENDATION'
+    SAVED_RECOMMENDATION = 'SAVED_RECOMMENDATION'
 
 
 @dataclass_json
@@ -34,3 +37,4 @@ class CampaignLogEvent(UserFacingDataType):
     prospect_id: Optional[str] = None
     thread_id: Optional[str] = None
     sequence_step_id: Optional[str] = None
+    recommendation_id: Optional[str] = None
